/* Reset box sizing */
*, ::after, ::before {
  box-sizing: border-box;
}

/* Colori */
body {
  background-color: #212121;
  color: #fff;
  font-family: monospace, serif;
  letter-spacing: 0.05em;
  margin: 0;
  padding: 0;
}

h1 {
  font-size: 23px;
}

.form {
  width: 300px;
  padding: 64px 15px 24px;
  margin: 0 auto;
}

.form .control {
  margin-bottom: 24px;
}

.form .control input {
  width: 100%;
  padding: 14px 16px;
  border: 0;
  background: transparent;
  color: #fff;
  font-family: monospace, serif;
  letter-spacing: 0.05em;
  font-size: 16px;
}

.form .control input:hover,
.form .control input:focus {
  outline: none;
  border: 0;
}

.btn {
  width: 100%;
  display: block;
  padding: 14px 16px;
  background: transparent;
  outline: none;
  border: 0;
  color: #fff;
  letter-spacing: 0.1em;
  font-weight: bold;
  font-family: monospace;
  font-size: 16px;
  cursor: pointer;
}

/* Blocchi e sfondi */
.block-cube {
  position: relative;
}

.block-cube .bg-top {
  position: absolute;
  height: 10px;
  background: linear-gradient(90deg, rgba(2,0,36,1) 0%, rgba(52,9,121,1) 37%, rgba(0,212,255,1) 94%);
  bottom: 100%;
  left: 5px;
  right: -5px;
  transform: skew(-45deg, 0);
  margin: 0;
}

.block-cube .bg-top .bg-inner {
  bottom: 0;
  position: relative;
  height: 100%;
}

.block-cube .bg-right {
  position: absolute;
  background: rgba(0,212,255,1);
  top: -5px;
  z-index: 0;
  bottom: 5px;
  width: 10px;
  left: 100%;
  transform: skew(0, -45deg);
}

.block-cube .bg-right .bg-inner {
  left: 0;
  position: relative;
  height: 100%;
}

.block-cube .bg {
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  background: linear-gradient(90deg, rgba(2,0,36,1) 0%, rgba(52,9,121,1) 37%, rgba(0,212,255,1) 94%);
}

.block-cube .bg .bg-inner {
  transition: all 0.2s ease-in-out;
  background: #212121;
  position: absolute;
  left: 2px;
  top: 2px;
  right: 2px;
  bottom: 2px;
}

.block-cube .text {
  position: relative;
  z-index: 2;
}

.block-input input {
  position: relative;
  z-index: 2;
}

.block-input input:focus ~ .bg-right .bg-inner,
.block-input input:focus ~ .bg-top .bg-inner,
.block-input input:focus ~ .bg .bg-inner {
  top: 100%;
  background: rgba(255, 255, 255, 0.5);
}

.block-input .bg-top,
.block-input .bg-right,
.block-input .bg {
  background: rgba(255, 255, 255, 0.5);
  transition: background 0.2s ease-in-out;
}

.block-input .bg-right .bg-inner,
.block-input .bg-top .bg-inner {
  transition: all 0.2s ease-in-out;
}

.block-input:hover .bg-top,
.block-input:hover .bg-right,
.block-input:hover .bg,
.block-input:focus .bg-top,
.block-input:focus .bg-right,
.block-input:focus .bg {
  background: rgba(255, 255, 255, 0.8);
}

.block-cube-hover:focus .bg .bg-inner,
.block-cube-hover:hover .bg .bg-inner {
  top: 100%;
}
